@@ -39,7 +39,6 @@
 #include "fd.h"
 #include "err_detail_type.h"
 #include "errorpage.h"
-#include "HttpHdrContRange.h"
 #include "HttpReply.h"
 #include "HttpRequest.h"
 #include "Server.h"
@@ -76,8 +75,7 @@ ServerStateData::ServerStateData(FwdState *theFwdState): AsyncJob("ServerStateDa
 
     entry->lock();
 
-    request = fwd->request;
-    HTTPMSGLOCK(request);
+    request = HTTPMSGLOCK(fwd->request);
 }
 
 ServerStateData::~ServerStateData()
@@ -149,8 +147,7 @@ ServerStateData::setVirginReply(HttpReply *rep)
     debugs(11,5, HERE << this << " setting virgin reply to " << rep);
     assert(!theVirginReply);
     assert(rep);
-    theVirginReply = rep;
-    HTTPMSGLOCK(theVirginReply);
+    theVirginReply = HTTPMSGLOCK(rep);
     return theVirginReply;
 }
 
@@ -168,8 +165,7 @@ ServerStateData::setFinalReply(HttpReply *rep)
 
     assert(!theFinalReply);
     assert(rep);
-    theFinalReply = rep;
-    HTTPMSGLOCK(theFinalReply);
+    theFinalReply = HTTPMSGLOCK(rep);
 
     // give entry the reply because haveParsedReplyHeaders() expects it there
     entry->replaceHttpReply(theFinalReply, false); // but do not write yet
@@ -384,7 +380,7 @@ ServerStateData::sentRequestBody(const CommIoCbParams &io)
     if (io.flag) {
         debugs(11, DBG_IMPORTANT, "sentRequestBody error: FD " << io.fd << ": " << xstrerr(io.xerrno));
         ErrorState *err;
-        err = new ErrorState(ERR_WRITE_ERROR, Http::scBadGateway, fwd->request);
+        err = new ErrorState(ERR_WRITE_ERROR, HTTP_BAD_GATEWAY, fwd->request);
         err->xerrno = io.xerrno;
         fwd->fail(err);
         abortTransaction("I/O error while sending request body");
@@ -509,7 +505,7 @@ ServerStateData::maybePurgeOthers()
         return;
 
     // and probably only if the response was successful
-    if (theFinalReply->sline.status() >= 400)
+    if (theFinalReply->sline.status >= 400)
         return;
 
     // XXX: should we use originalRequest() here?
@@ -526,11 +522,6 @@ ServerStateData::haveParsedReplyHeaders()
 {
     Must(theFinalReply);
     maybePurgeOthers();
-
-    // adaptation may overwrite old offset computed using the virgin response
-    const bool partial = theFinalReply->content_range &&
-                         theFinalReply->sline.status() == Http::scPartialContent;
-    currentOffset = partial ? theFinalReply->content_range->spec.offset : 0;
 }
 
 HttpRequest *
@@ -667,7 +658,7 @@ ServerStateData::noteAdaptationAnswer(const Adaptation::Answer &answer)
 
     switch (answer.kind) {
     case Adaptation::Answer::akForward:
-        handleAdaptedHeader(const_cast<HttpMsg*>(answer.message.getRaw()));
+        handleAdaptedHeader(answer.message);
         break;
 
     case Adaptation::Answer::akBlock:
@@ -835,7 +826,7 @@ ServerStateData::handleAdaptationAborted(bool bypassable)
 
     if (entry->isEmpty()) {
         debugs(11,9, HERE << "creating ICAP error entry after ICAP failure");
-        ErrorState *err = new ErrorState(ERR_ICAP_FAILURE, Http::scInternalServerError, request);
+        ErrorState *err = new ErrorState(ERR_ICAP_FAILURE, HTTP_INTERNAL_SERVER_ERROR, request);
         err->detailError(ERR_DETAIL_ICAP_RESPMOD_EARLY);
         fwd->fail(err);
         fwd->dontRetry(true);
@@ -869,7 +860,7 @@ ServerStateData::handleAdaptationBlocked(const Adaptation::Answer &answer)
     if (page_id == ERR_NONE)
         page_id = ERR_ACCESS_DENIED;
 
-    ErrorState *err = new ErrorState(page_id, Http::scForbidden, request);
+    ErrorState *err = new ErrorState(page_id, HTTP_FORBIDDEN, request);
     err->detailError(ERR_DETAIL_RESPMOD_BLOCK_EARLY);
     fwd->fail(err);
     fwd->dontRetry(true);
@@ -908,7 +899,7 @@ ServerStateData::noteAdaptationAclCheckDone(Adaptation::ServiceGroupPointer grou
 void
 ServerStateData::sendBodyIsTooLargeError()
 {
-    ErrorState *err = new ErrorState(ERR_TOO_BIG, Http::scForbidden, request);
+    ErrorState *err = new ErrorState(ERR_TOO_BIG, HTTP_FORBIDDEN, request);
     fwd->fail(err);
     fwd->dontRetry(true);
     abortTransaction("Virgin body too large.");
